"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@typescript-eslint/utils");
const createRule_1 = __importDefault(require("../util/createRule"));
const enforceReactMemo = (0, createRule_1.default)({
    name: 'enforce-react-memo',
    meta: {
        docs: {
            description: 'React components should be memoized',
            recommended: 'warn',
        },
        messages: {
            general: 'Memoize this component',
        },
        type: 'problem',
        schema: [
            {
                type: 'object',
                properties: {},
                additionalProperties: false,
            },
        ],
    },
    defaultOptions: [{ ignoreHooks: [] }],
    create(context) {
        return {
            ExportNamedDeclaration(node) {
                var _a;
                if (((_a = node.declaration) === null || _a === void 0 ? void 0 : _a.type) ===
                    utils_1.AST_NODE_TYPES.VariableDeclaration) {
                    const declaration = node.declaration.declarations[0];
                    if (declaration.type === utils_1.AST_NODE_TYPES.VariableDeclarator) {
                        const init = declaration.init;
                        if (!init) {
                            // Not a component
                            return;
                        }
                        const name = declaration.id.type === utils_1.AST_NODE_TYPES.Identifier
                            ? declaration.id.name
                            : undefined;
                        if (init.type ===
                            utils_1.AST_NODE_TYPES.ArrowFunctionExpression &&
                            name &&
                            // Shallow checking for component declaration
                            name.charAt(0) === name.charAt(0).toUpperCase()) {
                            // TODO: Only report if component
                            context.report({
                                node,
                                messageId: 'general',
                            });
                            return;
                        }
                        if (init.type === utils_1.AST_NODE_TYPES.CallExpression) {
                            const callee = init.callee;
                            if (callee.type === utils_1.AST_NODE_TYPES.Identifier) {
                                if (callee.name !== 'memo') {
                                    context.report({
                                        node,
                                        messageId: 'general',
                                    });
                                    return;
                                }
                            }
                        }
                    }
                }
            },
            ExportDefaultDeclaration(node) {
                if (node.declaration.type === utils_1.AST_NODE_TYPES.Identifier) {
                    const identifier = node.declaration.name;
                    const declarationNode = node.parent.body.find(item => {
                        if (item.type === utils_1.AST_NODE_TYPES.VariableDeclaration) {
                            const declaration = item.declarations[0];
                            if (declaration.type ===
                                utils_1.AST_NODE_TYPES.VariableDeclarator) {
                                const id = declaration.id;
                                if (id.type === utils_1.AST_NODE_TYPES.Identifier) {
                                    return id.name === identifier;
                                }
                            }
                        }
                    });
                    if (!declarationNode) {
                        return;
                    }
                    const init = declarationNode.declarations[0].init;
                    if (!init) {
                        return;
                    }
                    if (init.type === utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                        context.report({
                            node: declarationNode,
                            messageId: 'general',
                        });
                        return;
                    }
                    if (init.type === utils_1.AST_NODE_TYPES.CallExpression) {
                        const callee = init.callee;
                        if (callee.type === utils_1.AST_NODE_TYPES.Identifier) {
                            if (callee.name !== 'memo') {
                                context.report({
                                    node,
                                    messageId: 'general',
                                });
                                return;
                            }
                        }
                    }
                }
            },
        };
    },
});
exports.default = enforceReactMemo;
