"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ts_eslint_1 = require("@typescript-eslint/utils/dist/ts-eslint");
const handleMutationError_1 = __importDefault(require("../../rules/handleMutationError"));
const ruleTester = new ts_eslint_1.RuleTester({
    parser: require.resolve('@typescript-eslint/parser'),
});
ruleTester.run('handle-mutation-error', handleMutationError_1.default, {
    valid: [
        {
            code: `const [runMutation, { error, loading }] = useMutation<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
        },
        {
            code: `const [runMutation, { loading }] = useMutation<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            options: [{ ignoreHooks: ['useMutation'] }],
        },
    ],
    invalid: [
        {
            code: `const [runMutation, { loading }] = useMutation<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            errors: [{ messageId: 'general' }],
        },
        {
            code: `const [runMutation] = useMutation<CheckoutQueryResultData>(
                    checkoutQuery,
                    {
                        variables: {
                            store,
                            language,
                            cartType,
                        },
                        pollInterval: 30_000,
                        fetchPolicy: 'network-only',
                        notifyOnNetworkStatusChange: true,
                        onCompleted: () => {
                            onCompleted();
                            if (!initialized) {
                                setInitialized(true);
                            }
                        },
                    }
                );
            `,
            errors: [{ messageId: 'general' }],
        },
    ],
});
